@@ -6,11 +6,11 @@ test_that("can read sheets with inlineStr", {
 })
 
 test_that("can read files with and without extension [xls]", {
-  file.copy(test_sheet("iris-excel-xls.xls"), "iris-xls-no-ending")
-  on.exit(file.remove("iris-xls-no-ending"))
+  iris_xls_no_ending <- withr::local_tempfile()
+  file.copy(test_sheet("iris-excel-xls.xls"), iris_xls_no_ending)
   iris_xls <- read_excel(test_sheet("iris-excel-xls.xls"))
-  iris_guess <- read_excel("iris-xls-no-ending")
-  iris_explicit <- read_xls("iris-xls-no-ending")
+  iris_guess <- read_excel(iris_xls_no_ending)
+  iris_explicit <- read_xls(iris_xls_no_ending)
   expect_equal(iris_xls, iris_guess)
   expect_equal(iris_xls, iris_explicit)
 })
@@ -111,12 +111,12 @@ test_that("non-ASCII filenames can be read", {
   expect_true(file.exists(tricky_xlsx_file))
   on.exit(file.remove(tricky_xls_file))
   on.exit(file.remove(tricky_xlsx_file))
-  expect_error_free(read_xls(tricky_xls_file))
-  expect_error_free(read_xlsx(tricky_xlsx_file))
+  expect_no_error(read_xls(tricky_xls_file))
+  expect_no_error(read_xlsx(tricky_xlsx_file))
 })
 
 test_that("styles and sharedStrings parts can be absent", {
-  expect_error_free(
+  expect_no_error(
     df <- read_xlsx(test_sheet("no-styles-or-sharedStrings-parts.xlsx"))
   )
   expect_identical(df$Language[1], "german")
